@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.h 1376 2006-09-13 19:01:42Z chpe $
+ *  $Id$
  */
 
 #ifndef ERROR_VIEWER_MOZILLA_HELPERS_H
@@ -23,7 +23,7 @@
 
 #include <glib.h>
 
-#include <epiphany/ephy-embed.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
