@@ -31,8 +31,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#include <epiphany/ephy-embed-container.h>
-#include <epiphany/ephy-window.h>
+#include <epiphany/epiphany.h>
 
 #include <string.h>
 
